SDK for yeswehack


# Build from source

`make build` (or `poetry build`)

# Installation

## Developer

### Requirements

- [`poetry`](https://python-poetry.org/) (`pip install poetry`)

### Installation

`make install` (or `poetry install`): creates a virtualenv and install dependencies

## From pip

```
pip install yeswehack
```

## From wheel

```
pip install path/to/yeswehack-wheel.whl
```

# Getting starting with YesWeHack Python SDK

## API Module

In this python module, we define object mapping to YesWeHack API Object.
